import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:unicons/unicons.dart';

import 'package:random/cubit/bottom_nav_cubit.dart';
import 'package:random/cubit/settings_cubit.dart';
import 'package:random/config/theme.dart';
import 'package:random/models/interface_type.dart';

class SettingsForm extends StatefulWidget {
  const SettingsForm({super.key});

  @override
  State<SettingsForm> createState() => _SettingsFormState();
}

class _SettingsFormState extends State<SettingsForm> {
  final apiUrlController = TextEditingController();
  final securityTokenController = TextEditingController();
  final List<Widget> interfaceTypesWidgets = InterfaceTypes.selectWidgets;

  @override
  void dispose() {
    apiUrlController.dispose();
    securityTokenController.dispose();
    super.dispose();
  }

  List<bool> _selectedInterfaceType = <bool>[];

  @override
  Widget build(BuildContext context) {
    SettingsCubit settings = BlocProvider.of<SettingsCubit>(context);

    apiUrlController.text = settings.getApiUrl();
    securityTokenController.text = settings.getSecurityToken();
    if (_selectedInterfaceType.length != 2) {
      _selectedInterfaceType = <bool>[
        settings.getInterfaceType() == InterfaceType.basic,
        settings.getInterfaceType() == InterfaceType.expert,
      ];
    }

    void saveSettings() {
      BlocProvider.of<SettingsCubit>(context).setValues(
        apiUrl: apiUrlController.text,
        securityToken: securityTokenController.text,
        interfaceType: _selectedInterfaceType[0] ? InterfaceType.basic : InterfaceType.expert,
      );

      BlocProvider.of<BottomNavCubit>(context).getDemoPage();
    }

    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        Text('settings_label_api_url').tr(),
        TextFormField(
          controller: apiUrlController,
          decoration: InputDecoration(
            border: UnderlineInputBorder(),
          ),
        ),
        SizedBox(height: 16),
        Text('settings_label_security_token').tr(),
        TextFormField(
          controller: securityTokenController,
          decoration: InputDecoration(
            border: UnderlineInputBorder(),
          ),
        ),
        SizedBox(height: 16),
        Text('settings_label_interface_type').tr(),
        ToggleButtons(
          direction: Axis.horizontal,
          onPressed: (int index) {
            setState(() {
              _selectedInterfaceType = index == 0 ? [true, false] : [false, true];
            });
          },
          borderRadius: const BorderRadius.all(Radius.circular(8)),
          selectedBorderColor: appTheme.primaryColor,
          selectedColor: appTheme.colorScheme.onSecondary,
          fillColor: appTheme.colorScheme.secondary,
          color: appTheme.primaryColor,
          constraints: const BoxConstraints(
            minHeight: 40.0,
            minWidth: 80.0,
          ),
          isSelected: _selectedInterfaceType,
          children: interfaceTypesWidgets,
        ),
        SizedBox(height: 20),
        ElevatedButton(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Icon(UniconsLine.save),
              SizedBox(width: 8),
              Text('settings_button_save').tr(),
            ],
          ),
          onPressed: () => saveSettings(),
        ),
      ],
    );
  }
}
